#
#
#  Example demonstrating the combination of Blender and ASE
#  ========================================================
#
#
#  Start       : 2012-10-16
#  Last change : 2012-10-31
#  Author      : Clemens Barth (barth@root-1.de) 
#
#
#
#
#  This script has to be executed in a terminal with:
#
#         > python example1.py
#
#  After, push "0" on the number pad. You will then see the atoms 
#  from the camera point of view. 
#
#  Notes
#  =====
#  
#  1. You do not have to install the Atomic Blender - XYZ addon!
#
#  2. More details about the options see:
#     http://wiki.blender.org/index.php/Extensions:2.6/Py/Scripts/Import-Export/XYZ
#
# 




from ase.lattice.surface import *
from ase.io import write
from ase.io import read
from ase import Atoms
from numpy import array
from math import pi, cos, sin
import os

# This is the Blender library
from ase.blender import blend_show



# ___________________________________________________ ASE: Creation of a surface

# Create first a fcc(111) slab of aluminium atoms
slab = fcc111('Al', size=(2,2,3))
# Put a hydrogen on top of it
add_adsorbate(slab, 'H', 1.5, 'ontop')
# Center
slab.center(vacuum=10.0, axis=2)
# Repeat the slab
slab = slab.repeat((15,15,1))


# _______________________________________________________ Visualization: Blender



# Call Blender and load the atoms.
blend_show(slab)


                        
"""
Function: blend_show(slab, ****kwargs)
    
slab                     # Either a 'Atom' structure or path to a xyz 
                         # ASCII file. Blender accepts xyz files with several 
                         # frames, which can be used for animations.

**kwargs, optional 
==================
mesh = False             # Use mesh balls instead of NURBS
mesh_azimuth = 32        # If mesh balls, number of sectors in azimut
mesh_zenith = 32         # If mesh balls, number of sectors in zenith
scale_ballradius = 1.0   # Scale factor to scalle all atom radii
atomradius = "1"         # Atom radii: '0' pre-defined (default atomic radii)
                         #             '1' atomic radii
                         #             '2' van der Waals
scale_distances = 1.0    # Scale factor to scalle all distances
use_center = True        # Center the atomic structure into the center (0,0,0)
                         # of the world
use_center_all = True    # ...
use_camera = False       # Use a camera. The camera is placed into a distance
                         # such that the atomic structure can be well seen from
                         # the camera. Push '0' on the number pad after Blender 
                         # has loaded the structure. You see the structure from 
                         # the camera point of view
use_lamp = True          # Use also a point light source 
load_frames = False      # Load the frames, if present
frame_skip = 0           # Skip each nth frame.      
frame_delta = 1          # Introduce more frames between each pair of frames,
                         # and interpolate the movement. frame_delta = 1: means 
                         # no additional frames.
blender_close" = False   # Close Blender after having opened. This is important 
                         # for the rendering without the Blender UI opened. See
                         # function blend_render.
blender_save_file" = ""  # Save the Blender scene into a Blender .blend file. 
                         # This will be always done if the string is not empty.

All values are default values. For more details: 
http://wiki.blender.org/index.php/Extensions:2.6/Py/Scripts/Import-Export/XYZ
"""
                        
                        
                        
                        
 
    
    
    
    
    
    
